pub fn wait_for_state(
coord: &Coordinator,
session_id: &str,
target: SessionState,
timeout: Duration,
) -> boolExpand description
Wait for a session to reach a target state, polling.
pub fn wait_for_state(
coord: &Coordinator,
session_id: &str,
target: SessionState,
timeout: Duration,
) -> boolWait for a session to reach a target state, polling.